==> xlog_1.4.orig.tar.gz: xlog-1.4/src/utils.h <==
/*
 * xlog - GTK+ logging program for amateur radio operators
 * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 * utils.h
 */

gchar *setlocation (gdouble lat, gint NS, gdouble lon, gint EW);
void makebandoptionmenu (gchar *bands);
void makemodeoptionmenu (gchar *modes);
void deletespaces (gchar ** split);
void update_statusbar (gchar * string);
gboolean remove_prefixes (gchar * key, gpointer value, gpointer user_data);
void save_windowsize_and_cleanup (void);
gchar *band_enum2char (guint band_enum);
gint freq2enum (gchar * str);
gchar *finddot (gchar * qsoband);
gchar *findband (gchar * arg);
gchar *getdate (void);
gchar *gettime (void);
gchar *lookup_mode (gint index);
gchar *lookup_band (gint index);
gint updateclock (void);
gchar *color_parse (gchar * value);
gint autosave (void);
void set_qsoframe (gpointer arg);
gboolean fileexist (gchar * path);
gchar *my_strreplace(const char *str, const char *delimiter, const char *replacement);
gchar *valid_awards_entry (gchar *a);

==> xlog-1.5.tar.gz: xlog-1.5/src/utils.h <==
/*
 * xlog - GTK+ logging program for amateur radio operators
 * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 * utils.h
 */

gchar *setlocation (gdouble lat, gint NS, gdouble lon, gint EW);
void makebandoptionmenu (gchar *bands);
void makemodeoptionmenu (gchar *modes);
void deletespaces (gchar ** split);
void update_statusbar (gchar * string);
gboolean remove_prefixes (gchar * key, gpointer value, gpointer user_data);
void save_windowsize_and_cleanup (void);
gchar *xloggetdate (void);
gchar *xloggettime (void);
gchar *lookup_mode (gint index);
gchar *lookup_band (gint index);
gint updateclock (void);
gchar *color_parse (gchar * value);
gint autosave (void);
void set_qsoframe (gpointer arg);
gboolean fileexist (gchar * path);
gchar *my_strreplace(const char *str, const char *delimiter, const char *replacement);
gchar *valid_awards_entry (gchar *a);
